@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.57 2003/12/17 16:33:03 kevinv Exp $
+ $Id: battstat_applet.c,v 1.59 2004/01/11 10:00:17 bviswa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -842,7 +842,10 @@ suspend_cb (BonoboUIComponent *uic,
 		      msg = g_strdup_printf(_("An error occured while launching the Suspend command: %s\nPlease try to correct this error"), err->message);
 	      } else {
 		      /* Probably because the shell_ret is != 0 */
-		      msg = g_strdup_printf(_("An error occured while launching the Suspend command, the command returned \"%d\"\nPlease try to correct this error"), shell_ret);
+		      if (battstat->suspend_cmd)
+		          msg = g_strdup_printf(_("The Suspend command '%s' was unsuccessful."), battstat->suspend_cmd);
+		      else
+		          msg = g_strdup_printf(_("The Suspend command was unsuccessful."));
 	      }
 	      battstat_error_dialog (PANEL_APPLET (battstat->applet), msg);
 	      g_free(msg);
@@ -1506,6 +1509,7 @@ battstat_applet_fill (PanelApplet *applet)
 {
   ProgressData *battstat;
   struct stat statbuf;
+  AtkObject *atk_widget;
 
   if (DEBUG) g_print("main()\n");
   
@@ -1599,6 +1603,11 @@ battstat_applet_fill (PanelApplet *applet)
 					NULL);
   }
 
+  atk_widget = gtk_widget_get_accessible (battstat->applet);
+  if (GTK_IS_ACCESSIBLE (atk_widget)) {
+	  atk_object_set_name (atk_widget, _("Battery Charge Monitor"));
+	  atk_object_set_description(atk_widget, _("Monitor a laptop's remaining power"));
+  }
 
   return TRUE;
 }
