@@ -53,7 +53,7 @@
 #define CDPLAYER_EJECT          "media-eject"
 
 /* Function prototypes */
-static gboolean applet_factory (PanelApplet *applet, const gchar *iid, gpointer data);
+static gboolean cdplayer_applet_factory (PanelApplet *applet, const gchar *iid, gpointer data);
 static gboolean applet_fill (PanelApplet *applet);
 static void cdplayer_load_config(CDPlayerData *cd);
 static void show_error(CDPlayerData *cd);
@@ -121,11 +121,11 @@ PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_CDPlayerApplet_Factory",
 			     PANEL_TYPE_APPLET,
                              "cdplayer",
                              "0",
-                              applet_factory,
+                              cdplayer_applet_factory,
                               NULL)
 
 static gboolean
-applet_factory (PanelApplet *applet,
+cdplayer_applet_factory (PanelApplet *applet,
         const gchar *iid,
         gpointer     data)
 {
@@ -145,8 +145,13 @@ applet_fill (PanelApplet *applet)
     BonoboUIComponent *component;
     GtkTooltips *tooltips;
     int err;
+    GtkIconInfo *icon_info;
 
-    gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-cdplayer-icon.png");
+    icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "gnome-cdplayer-icon", 48, 0);
+    if (icon_info) {
+        gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
+        gtk_icon_info_free (icon_info);
+    }
     panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
     cdplayer_init_stock_icons ();
       
@@ -212,6 +217,17 @@ applet_fill (PanelApplet *applet)
                                        applet_menu_verbs,
                                        cd);
 
+    if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+	    BonoboUIComponent *popup_component;
+
+	    popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+
+	    bonobo_ui_component_set_prop (popup_component,
+					  "/commands/Preferences",
+					  "hidden", "1",
+					  NULL);
+    }
+
     component = panel_applet_get_popup_component (PANEL_APPLET (applet));
 
     g_signal_connect (component, "ui-event", G_CALLBACK (ui_component_event), cd);
@@ -293,7 +309,7 @@ cdplayer_destroy(GtkWidget * widget, gpointer data)
         gtk_timeout_remove(cd->timeout);
     cd->timeout = 0;
     /* Since the applet is being destroyed, stop playing cd */
-    if(cd_try_open(cd, &err))
+    if(cd_try_open(cd, &err) && cd->played_by_applet == 1)
         cdrom_stop(cd->cdrom_device);
     cd_close (cd);
 
@@ -303,6 +319,11 @@ cdplayer_destroy(GtkWidget * widget, gpointer data)
         g_object_set_data (G_OBJECT (cd->panel.applet), "tooltips", NULL);
     }
    
+    if (cd->play_image)
+        g_object_unref (cd->play_image);
+    if (cd->pause_image)
+        g_object_unref (cd->pause_image);
+
     if (cd->time_description)
         g_free(cd->time_description);
     if (cd->track_description)
@@ -557,7 +578,6 @@ about_cb (BonoboUIComponent *component,
     static GtkWidget   *about     = NULL;
     GdkPixbuf	       *pixbuf;
     GError	       *error     = NULL;
-    gchar	       *file;
 
     static const gchar *authors[] =
     {
@@ -581,12 +601,10 @@ about_cb (BonoboUIComponent *component,
         return;
     }
     
-    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-cdplayer-icon.png", FALSE, NULL);
-    pixbuf = gdk_pixbuf_new_from_file (file, &error);
-    g_free (file);
+    pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "gnome-cdplayer-icon", 48, 0, &error);
     
     if (error) {
-    	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+    	g_warning (G_STRLOC ": cannot open icon %s: %s", "gnome-cdplayer-icon", error->message);
 	g_error_free (error);
     }
     
@@ -914,6 +932,7 @@ cdplayer_play_pause(GtkWidget * w, gpointer data)
         case DISC_PAUSED:
 	    cdplayer_update_play_pause_button (cd, PAUSE_IMAGE);
             cdrom_resume(cd->cdrom_device);
+            cd->played_by_applet = 1;
             break;
         case DISC_COMPLETED:
         case DISC_STOP:
@@ -922,6 +941,8 @@ cdplayer_play_pause(GtkWidget * w, gpointer data)
             cdrom_read_track_info(cd->cdrom_device);
             ret = cdrom_play(cd->cdrom_device, cd->cdrom_device->track0,
                    cd->cdrom_device->track1);
+            if (ret == DISC_NO_ERROR)
+                   cd->played_by_applet = 1;
             break;
         }
     } else if(status == DISC_TRAY_OPEN) {
@@ -929,6 +950,8 @@ cdplayer_play_pause(GtkWidget * w, gpointer data)
         cdrom_read_track_info(cd->cdrom_device);
         ret = cdrom_play(cd->cdrom_device, cd->cdrom_device->track0,
                cd->cdrom_device->track1);
+        if (ret == DISC_NO_ERROR)
+               cd->played_by_applet = 1;
     }
 
     if (ret == DISC_DEVICE_BUSY) {
@@ -968,28 +991,38 @@ static void
 cdplayer_prev(GtkWidget * w, gpointer data)
 {
     CDPlayerData *cd = data;
+    cdrom_device_status_t stat;
+    int status;
     int err;
     if(!cd_try_open(cd, &err)) {
         if (err == EACCES)
             show_error (cd);
         return;
     }
-    cdrom_prev(cd->cdrom_device);
+    status = cdrom_get_status(cd->cdrom_device, &stat);
+    if (status == DISC_NO_ERROR && stat.audio_status != DISC_PLAY)
+        cd->played_by_applet = 1;
 
+    cdrom_prev(cd->cdrom_device);
 }
 
 static void 
 cdplayer_next(GtkWidget * w, gpointer data)
 {
     CDPlayerData *cd = data;
+    cdrom_device_status_t stat;
+    int status;
     int err;
     if(!cd_try_open(cd, &err)) {
         if (err == EACCES)
             show_error (cd);
         return;
     }
-    cdrom_next(cd->cdrom_device);
+    status = cdrom_get_status(cd->cdrom_device, &stat);
+    if (status == DISC_NO_ERROR && stat.audio_status != DISC_PLAY)
+        cd->played_by_applet = 1;
 
+    cdrom_next(cd->cdrom_device);
 }
 
 static void 
@@ -1016,9 +1049,9 @@ cdplayer_eject(GtkWidget * w, gpointer data)
         cdrom_eject(cd->cdrom_device);
     else
         cdrom_eject(cd->cdrom_device);
+    cd->played_by_applet = 0;
     cd_close(cd);
     return;
-        w = NULL;
 }
 
 static void
@@ -1206,6 +1239,7 @@ cdplayer_update_play_pause_button (CDPlayerData *cd, gint id)
 	    gtk_container_remove (GTK_CONTAINER (cd->panel.play_control.play_pause), cd->current_image);
 	    gtk_container_add (GTK_CONTAINER (cd->panel.play_control.play_pause), cd->play_image);
 	    cd->current_image = cd->play_image;
+	    cd->played_by_applet = 0;
 	}
     }
     else {
