@@ -3,7 +3,6 @@
  */
 
 #include <config.h>
-#include <tgmath.h>
 #include <panel-applet.h>
 #include <egg-screen-help.h>
 #include "charpick.h"
@@ -324,6 +323,16 @@ add_palette (GtkMenuItem *menuitem, charpick_data *curr_data)
 		return;
 		
 	list = g_list_append (list, new);
+	if (curr_data->chartable == NULL) {
+		curr_data->chartable = list;
+		curr_data->charlist = curr_data->chartable->data;
+		build_table (curr_data);
+		if (key_writable (PANEL_APPLET (curr_data->applet), "current_list"))
+			panel_applet_gconf_set_string (PANEL_APPLET (curr_data->applet),
+						      "current_list", 
+					  	       curr_data->charlist, NULL);
+	}
+	
 	save_chartable (curr_data);
   	populate_menu (curr_data);
 }
@@ -428,7 +437,7 @@ build_table(charpick_data *p_curr_data)
   GtkWidget *toggle_button[len];
   gchar *charlist;
   gint width, height;
-  gint max_width=0, max_height=0;
+  gint max_width=1, max_height=1;
   gint size_ratio;
   
   if (p_curr_data->box)
@@ -734,14 +743,16 @@ set_atk_name_description (GtkWidget *widget, const gchar *name,
   /* return if gail is not loaded */
   if (GTK_IS_ACCESSIBLE (aobj) == FALSE)
      return;
-  atk_object_set_name (aobj, name);
-  atk_object_set_description (aobj, description);
+  if (name)
+     atk_object_set_name (aobj, name);
+  if (description)
+     atk_object_set_description (aobj, description);
 }
 
 static void
 make_applet_accessible (GtkWidget *applet)
 {
-  set_atk_name_description (applet, _("Character Palette"), NULL);
+  set_atk_name_description (applet, _("Character Palette"), _("Insert characters"));
 }
 
 static gboolean
@@ -829,6 +840,18 @@ charpicker_applet_fill (PanelApplet *applet)
                                      NULL,
 			             charpick_applet_menu_verbs,
 			             curr_data);
+
+  if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+	  BonoboUIComponent *popup_component;
+
+	  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+
+	  bonobo_ui_component_set_prop (popup_component,
+					"/commands/Preferences",
+					"hidden", "1",
+					NULL);
+  }
+
 			             
   populate_menu (curr_data);
   
