@@ -33,8 +33,9 @@ typedef struct
 typedef struct 
 {
 	/* Applet */
+	GtkWidget   *about_dialog;
 	PanelApplet *applet;
-	GtkWidget   *fixed;
+	GtkWidget   *vbox;
 	GtkWidget   *hbox;
 	GtkWidget   *eyes[MAX_EYES];
 	guint        timeout_id;
