@@ -626,6 +626,8 @@ prefs_response_cb (GtkDialog *dialog, gint response, gpointer data)
 static void
 wireless_applet_destroy (WirelessApplet *applet, gpointer horse)
 {
+	int i;
+
 	g_free (applet->device);
 
 	g_list_foreach (applet->devices, (GFunc)g_free, NULL);
@@ -636,6 +638,9 @@ wireless_applet_destroy (WirelessApplet *applet, gpointer horse)
 		applet->timeout_handler_id = 0;
 	}
 
+	for (i = 0; i < PIX_NUMBER; i++)
+		g_object_unref (applet->pixmaps[i]);
+
 	if (applet->prefs) {
 		gtk_widget_destroy (applet->prefs);
 		applet->prefs = NULL;
@@ -643,6 +648,8 @@ wireless_applet_destroy (WirelessApplet *applet, gpointer horse)
 
 	if (applet->file)
 		fclose (applet->file);
+	if (applet->tips)
+		g_object_unref (applet->tips);
 }
 
 static void
@@ -727,6 +734,8 @@ static void change_orient_cb(PanelApplet *pa, gint s, WirelessApplet *applet)
 static GtkWidget *
 wireless_applet_new (WirelessApplet *applet)
 {
+	AtkObject *atk_obj;
+
 	panel_applet_set_flags (PANEL_APPLET (applet), PANEL_APPLET_EXPAND_MINOR);
 
 	/* this ensures that properties are loaded */
@@ -736,6 +745,8 @@ wireless_applet_new (WirelessApplet *applet)
 	setup_widgets (applet);
 
 	applet->tips = gtk_tooltips_new ();
+	g_object_ref (applet->tips);
+	gtk_object_sink (GTK_OBJECT (applet->tips));
 	applet->prefs = NULL;
 
 	g_signal_connect (GTK_OBJECT (applet),"destroy",
@@ -749,6 +760,17 @@ wireless_applet_new (WirelessApplet *applet)
 			wireless_menu_verbs,
 			applet);
 
+	if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/WirelessProperties",
+					      "hidden", "1",
+					      NULL);
+	}
+
 	start_file_read (applet);
 	wireless_applet_timeout_handler (applet);
 
@@ -756,6 +778,13 @@ wireless_applet_new (WirelessApplet *applet)
 		(CFG_UPDATE_INTERVAL * 1000,
 		 (GtkFunction)wireless_applet_timeout_handler,
 		 applet);
+
+	atk_obj = gtk_widget_get_accessible (GTK_WIDGET (applet));
+
+	if (GTK_IS_ACCESSIBLE (atk_obj)) {
+		atk_object_set_name (atk_obj, _("Wireless Link Monitor"));
+		atk_object_set_description (atk_obj, _("This utility shows the status of a wireless link"));
+	}
 		 
 	g_signal_connect (G_OBJECT (applet), "change_size",
 				  G_CALLBACK (change_size_cb), applet);
